==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/GraphConstructionServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/mining/v1beta/graph_construction.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class GraphConstructionServiceGrpc {

  private GraphConstructionServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.mining.v1beta.GraphConstructionService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GraphConstruction",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest, de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod;
    if ((getGraphConstructionMethod = GraphConstructionServiceGrpc.getGraphConstructionMethod) == null) {
      synchronized (GraphConstructionServiceGrpc.class) {
        if ((getGraphConstructionMethod = GraphConstructionServiceGrpc.getGraphConstructionMethod) == null) {
          GraphConstructionServiceGrpc.getGraphConstructionMethod = getGraphConstructionMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest, de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GraphConstruction"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse.getDefaultInstance()))
              .setSchemaDescriptor(new GraphConstructionServiceMethodDescriptorSupplier("GraphConstruction"))
              .build();
        }
      }
    }
    return getGraphConstructionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GraphConstructionServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceStub>() {
        @java.lang.Override
        public GraphConstructionServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GraphConstructionServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingStub>() {
        @java.lang.Override
        public GraphConstructionServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceBlockingStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GraphConstructionServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceFutureStub>() {
        @java.lang.Override
        public GraphConstructionServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceFutureStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class GraphConstructionServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGraphConstructionMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGraphConstructionMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
                de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>(
                  this, METHODID_GRAPH_CONSTRUCTION)))
          .build();
    }
  }

  /**
   */
  public static final class GraphConstructionServiceStub extends io.grpc.stub.AbstractAsyncStub<GraphConstructionServiceStub> {
    private GraphConstructionServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceStub(channel, callOptions);
    }

    /**
     */
    public void graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGraphConstructionMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class GraphConstructionServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<GraphConstructionServiceBlockingStub> {
    private GraphConstructionServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGraphConstructionMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class GraphConstructionServiceFutureStub extends io.grpc.stub.AbstractFutureStub<GraphConstructionServiceFutureStub> {
    private GraphConstructionServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> graphConstruction(
        de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGraphConstructionMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GRAPH_CONSTRUCTION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final GraphConstructionServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(GraphConstructionServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GRAPH_CONSTRUCTION:
          serviceImpl.graphConstruction((de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class GraphConstructionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GraphConstructionServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("GraphConstructionService");
    }
  }

  private static final class GraphConstructionServiceFileDescriptorSupplier
      extends GraphConstructionServiceBaseDescriptorSupplier {
    GraphConstructionServiceFileDescriptorSupplier() {}
  }

  private static final class GraphConstructionServiceMethodDescriptorSupplier
      extends GraphConstructionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    GraphConstructionServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GraphConstructionServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GraphConstructionServiceFileDescriptorSupplier())
              .addMethod(getGraphConstructionMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.5-sources.jar: de/uni_trier/recap/arg_services/mining/v1beta/GraphConstructionServiceGrpc.java <==
package de.uni_trier.recap.arg_services.mining.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/mining/v1beta/graph_construction.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class GraphConstructionServiceGrpc {

  private GraphConstructionServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.mining.v1beta.GraphConstructionService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GraphConstruction",
      requestType = de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest.class,
      responseType = de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
      de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest, de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> getGraphConstructionMethod;
    if ((getGraphConstructionMethod = GraphConstructionServiceGrpc.getGraphConstructionMethod) == null) {
      synchronized (GraphConstructionServiceGrpc.class) {
        if ((getGraphConstructionMethod = GraphConstructionServiceGrpc.getGraphConstructionMethod) == null) {
          GraphConstructionServiceGrpc.getGraphConstructionMethod = getGraphConstructionMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest, de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GraphConstruction"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse.getDefaultInstance()))
              .setSchemaDescriptor(new GraphConstructionServiceMethodDescriptorSupplier("GraphConstruction"))
              .build();
        }
      }
    }
    return getGraphConstructionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GraphConstructionServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceStub>() {
        @java.lang.Override
        public GraphConstructionServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static GraphConstructionServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingV2Stub>() {
        @java.lang.Override
        public GraphConstructionServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return GraphConstructionServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GraphConstructionServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceBlockingStub>() {
        @java.lang.Override
        public GraphConstructionServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceBlockingStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GraphConstructionServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<GraphConstructionServiceFutureStub>() {
        @java.lang.Override
        public GraphConstructionServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new GraphConstructionServiceFutureStub(channel, callOptions);
        }
      };
    return GraphConstructionServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGraphConstructionMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service GraphConstructionService.
   */
  public static abstract class GraphConstructionServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return GraphConstructionServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service GraphConstructionService.
   */
  public static final class GraphConstructionServiceStub
      extends io.grpc.stub.AbstractAsyncStub<GraphConstructionServiceStub> {
    private GraphConstructionServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceStub(channel, callOptions);
    }

    /**
     */
    public void graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getGraphConstructionMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service GraphConstructionService.
   */
  public static final class GraphConstructionServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<GraphConstructionServiceBlockingV2Stub> {
    private GraphConstructionServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGraphConstructionMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service GraphConstructionService.
   */
  public static final class GraphConstructionServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<GraphConstructionServiceBlockingStub> {
    private GraphConstructionServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse graphConstruction(de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getGraphConstructionMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service GraphConstructionService.
   */
  public static final class GraphConstructionServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<GraphConstructionServiceFutureStub> {
    private GraphConstructionServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GraphConstructionServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new GraphConstructionServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse> graphConstruction(
        de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getGraphConstructionMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GRAPH_CONSTRUCTION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GRAPH_CONSTRUCTION:
          serviceImpl.graphConstruction((de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getGraphConstructionMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionRequest,
              de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionResponse>(
                service, METHODID_GRAPH_CONSTRUCTION)))
        .build();
  }

  private static abstract class GraphConstructionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GraphConstructionServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.mining.v1beta.GraphConstructionProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("GraphConstructionService");
    }
  }

  private static final class GraphConstructionServiceFileDescriptorSupplier
      extends GraphConstructionServiceBaseDescriptorSupplier {
    GraphConstructionServiceFileDescriptorSupplier() {}
  }

  private static final class GraphConstructionServiceMethodDescriptorSupplier
      extends GraphConstructionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    GraphConstructionServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GraphConstructionServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GraphConstructionServiceFileDescriptorSupplier())
              .addMethod(getGraphConstructionMethod())
              .build();
        }
      }
    }
    return result;
  }
}
